pub fn detect_stacks(root: &Path) -> DetectedStacksExpand description
Detect project stacks from marker files in the given directory.
Reads package.json, go.mod, and Cargo.toml to determine which frameworks are in use.
pub fn detect_stacks(root: &Path) -> DetectedStacksDetect project stacks from marker files in the given directory.
Reads package.json, go.mod, and Cargo.toml to determine which frameworks are in use.