pub fn extract_pattern(
store: &AnnotationStore,
tag: &TagName,
) -> Option<Pattern>Expand description
Analyze all annotations of a tag and return the common pattern.
pub fn extract_pattern(
store: &AnnotationStore,
tag: &TagName,
) -> Option<Pattern>Analyze all annotations of a tag and return the common pattern.