pub fn matches_compound(
node: &dyn Matchable,
compound: &CompoundSelector,
) -> boolExpand description
Test if a single node matches a compound selector (tag + attributes).
pub fn matches_compound(
node: &dyn Matchable,
compound: &CompoundSelector,
) -> boolTest if a single node matches a compound selector (tag + attributes).