nav_select

Function nav_select 

pub fn nav_select(
    project_root: &ProjectRoot,
    file: &RelativePath,
    scope: Option<&NodeRef>,
    selector: &str,
) -> Result<NavResult, AqlError>
Select nodes matching a structural selector within a scope.

If scope is None, searches from the file root. If scope is Some(node_ref), searches within that node’s subtree.