pub fn sidecar_for_colocated(source: &RelativePath) -> RelativePathExpand description
Derive the colocated sidecar path from a source path.
src/api.ts → src/api.aqm
pub fn sidecar_for_colocated(source: &RelativePath) -> RelativePathDerive the colocated sidecar path from a source path.
src/api.ts → src/api.aqm