suggest_repairs

Function suggest_repairs 

pub fn suggest_repairs(
    store: &AnnotationStore,
    code_cache: Option<&CodeCache>,
) -> Vec<RepairSuggestion>
Find annotations with bindings that look potentially broken and suggest repairs based on other annotations and code element names. If code_cache is provided, code element names are included in the known names set.