pub fn validate(
store: &AnnotationStore,
manifest: &Manifest,
) -> Vec<ValidationResult>Expand description
Validate all loaded annotations against the manifest.
Parallelizes per-file validation via rayon when the fs feature is enabled.
pub fn validate(
store: &AnnotationStore,
manifest: &Manifest,
) -> Vec<ValidationResult>Validate all loaded annotations against the manifest.
Parallelizes per-file validation via rayon when the fs feature is enabled.