pub struct Delta {
pub binding: Binding,
pub unique_attrs: FxHashMap<AttrName, Value>,
pub file: RelativePath,
}Expand description
What is unique about a specific annotation relative to the pattern.
Fields
binding: BindingBinding key of this specific instance.
unique_attrs: FxHashMap<AttrName, Value>Attributes whose values differ from the most common value, or are unique to this instance.
file: RelativePathFile containing this annotation.