#[non_exhaustive]pub struct DiffChange {
pub file: RelativePath,
pub tag: TagName,
pub binding: Binding,
pub baseline_attrs: Vec<String>,
pub current_attrs: Vec<String>,
}Expand description
An annotation that changed between baseline and current.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file: RelativePathFile the annotation belongs to.
tag: TagNameAnnotation tag.
binding: BindingAnnotation binding.
baseline_attrs: Vec<String>Attributes in the baseline that differ or are absent in current.
current_attrs: Vec<String>Attributes in current that differ or are absent in baseline.