pub struct SidecarEdit {
pub start_byte: usize,
pub end_byte: usize,
pub new_text: String,
}Expand description
A text edit to apply to an .aqm sidecar file.
Fields
start_byte: usizeByte offset of the start of the region to replace.
end_byte: usizeByte offset of the end of the region to replace.
new_text: StringReplacement text (empty string = deletion).