pub struct SourceLocation {
pub file: RelativePath,
pub line: usize,
pub column: usize,
pub end_line: Option<usize>,
pub end_column: Option<usize>,
pub start_byte: usize,
pub end_byte: usize,
}Expand description
Location of a code element in a source file.
Fields
file: RelativePathRelative path to the source file.
line: usize1-based start line number.
column: usize0-based start column offset.
end_line: Option<usize>1-based end line number, if known.
end_column: Option<usize>0-based end column offset, if known.
start_byte: usizeByte offset of the start of this element in the source file.
end_byte: usizeByte offset of the end of this element in the source file.