pub fn filter_by_selector(
nodes: &[&dyn Matchable],
selector: &SelectorAst,
) -> Vec<usize>Expand description
Filter an array of flat nodes by a selector AST. Returns indices into the input slice for matched nodes.
pub fn filter_by_selector(
nodes: &[&dyn Matchable],
selector: &SelectorAst,
) -> Vec<usize>Filter an array of flat nodes by a selector AST. Returns indices into the input slice for matched nodes.