#[non_exhaustive]pub struct MutationResult {
pub source: String,
pub affected_nodes: Vec<NodeRef>,
}Expand description
Result of a mutation operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: StringThe modified source text.
affected_nodes: Vec<NodeRef>Updated node references for nodes affected by the mutation. After a mutation, previous node refs are stale — use these instead.